Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddApiKeyAuth ¶
Attach API key auth to the app header - 'XApiKey' - https://echo.labstack.com/docs/middleware/key-auth
func AddCompression ¶
add compression: https://echo.labstack.com/docs/middleware/gzip
func AddCors ¶
Attach CORS to API https://echo.labstack.com/docs/middleware/cors
func Logger ¶
Logger middleware logs the information about each HTTP request -https://echo.labstack.com/docs/middleware/logger
func RateLimiter ¶
Set a Rate limiter with a sliding window - https://echo.labstack.com/docs/middleware/rate-limiter
func Recover ¶
Recover middleware recovers from panics anywhere in the chain, prints stack trace and handles the control to the centralized HTTPErrorHandler - https://echo.labstack.com/docs/middleware/recover
Types ¶
This section is empty.